"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.group_api import GroupApi  # noqa: E501


class TestGroupApi(unittest.TestCase):
    """GroupApi unit test stubs"""

    def setUp(self):
        self.api = GroupApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_user_group_admin(self):
        """Test case for add_user_group_admin

        グループ管理者を追加  # noqa: E501
        """
        pass

    def test_add_user_group_member(self):
        """Test case for add_user_group_member

        グループメンバーを追加  # noqa: E501
        """
        pass

    def test_change_user_group_icon(self):
        """Test case for change_user_group_icon

        ユーザーグループのアイコンを変更  # noqa: E501
        """
        pass

    def test_create_user_group(self):
        """Test case for create_user_group

        ユーザーグループを作成  # noqa: E501
        """
        pass

    def test_delete_user_group(self):
        """Test case for delete_user_group

        ユーザーグループを削除  # noqa: E501
        """
        pass

    def test_edit_user_group(self):
        """Test case for edit_user_group

        ユーザーグループを編集  # noqa: E501
        """
        pass

    def test_edit_user_group_member(self):
        """Test case for edit_user_group_member

        グループメンバーを編集  # noqa: E501
        """
        pass

    def test_get_user_group(self):
        """Test case for get_user_group

        ユーザーグループを取得  # noqa: E501
        """
        pass

    def test_get_user_group_admins(self):
        """Test case for get_user_group_admins

        グループ管理者を取得  # noqa: E501
        """
        pass

    def test_get_user_group_members(self):
        """Test case for get_user_group_members

        グループメンバーを取得  # noqa: E501
        """
        pass

    def test_get_user_groups(self):
        """Test case for get_user_groups

        ユーザーグループのリストを取得  # noqa: E501
        """
        pass

    def test_remove_user_group_admin(self):
        """Test case for remove_user_group_admin

        グループ管理者を削除  # noqa: E501
        """
        pass

    def test_remove_user_group_member(self):
        """Test case for remove_user_group_member

        グループメンバーを削除  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
