"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.clip_api import ClipApi  # noqa: E501


class TestClipApi(unittest.TestCase):
    """ClipApi unit test stubs"""

    def setUp(self):
        self.api = ClipApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_clip_message(self):
        """Test case for clip_message

        メッセージをクリップフォルダに追加  # noqa: E501
        """
        pass

    def test_create_clip_folder(self):
        """Test case for create_clip_folder

        クリップフォルダを作成  # noqa: E501
        """
        pass

    def test_delete_clip_folder(self):
        """Test case for delete_clip_folder

        クリップフォルダを削除  # noqa: E501
        """
        pass

    def test_edit_clip_folder(self):
        """Test case for edit_clip_folder

        クリップフォルダ情報を編集  # noqa: E501
        """
        pass

    def test_get_clip_folder(self):
        """Test case for get_clip_folder

        クリップフォルダ情報を取得  # noqa: E501
        """
        pass

    def test_get_clip_folders(self):
        """Test case for get_clip_folders

        クリップフォルダのリストを取得  # noqa: E501
        """
        pass

    def test_get_clips(self):
        """Test case for get_clips

        フォルダ内のクリップのリストを取得  # noqa: E501
        """
        pass

    def test_get_message_clips(self):
        """Test case for get_message_clips

        自分のクリップを取得  # noqa: E501
        """
        pass

    def test_unclip_message(self):
        """Test case for unclip_message

        メッセージをクリップフォルダから除外  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
