"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.authentication_api import AuthenticationApi  # noqa: E501


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_my_external_accounts(self):
        """Test case for get_my_external_accounts

        外部ログインアカウント一覧を取得  # noqa: E501
        """
        pass

    def test_get_my_sessions(self):
        """Test case for get_my_sessions

        自分のログインセッションリストを取得  # noqa: E501
        """
        pass

    def test_link_external_account(self):
        """Test case for link_external_account

        外部ログインアカウントを紐付ける  # noqa: E501
        """
        pass

    def test_login(self):
        """Test case for login

        ログイン  # noqa: E501
        """
        pass

    def test_logout(self):
        """Test case for logout

        ログアウト  # noqa: E501
        """
        pass

    def test_revoke_my_session(self):
        """Test case for revoke_my_session

        セッションを無効化  # noqa: E501
        """
        pass

    def test_unlink_external_account(self):
        """Test case for unlink_external_account

        外部ログインアカウントの紐付けを解除  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
