"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.user_tag_api import UserTagApi  # noqa: E501


class TestUserTagApi(unittest.TestCase):
    """UserTagApi unit test stubs"""

    def setUp(self):
        self.api = UserTagApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_my_user_tag(self):
        """Test case for add_my_user_tag

        自分にタグを追加  # noqa: E501
        """
        pass

    def test_add_user_tag(self):
        """Test case for add_user_tag

        ユーザーにタグを追加  # noqa: E501
        """
        pass

    def test_edit_my_user_tag(self):
        """Test case for edit_my_user_tag

        自分のタグを編集  # noqa: E501
        """
        pass

    def test_edit_user_tag(self):
        """Test case for edit_user_tag

        ユーザーのタグを編集  # noqa: E501
        """
        pass

    def test_get_my_user_tags(self):
        """Test case for get_my_user_tags

        自分のタグリストを取得  # noqa: E501
        """
        pass

    def test_get_tag(self):
        """Test case for get_tag

        タグ情報を取得  # noqa: E501
        """
        pass

    def test_get_user_tags(self):
        """Test case for get_user_tags

        ユーザーのタグリストを取得  # noqa: E501
        """
        pass

    def test_remove_my_user_tag(self):
        """Test case for remove_my_user_tag

        自分からタグを削除します  # noqa: E501
        """
        pass

    def test_remove_user_tag(self):
        """Test case for remove_user_tag

        ユーザーからタグを削除します  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
