"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.stamp_api import StampApi  # noqa: E501


class TestStampApi(unittest.TestCase):
    """StampApi unit test stubs"""

    def setUp(self):
        self.api = StampApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_message_stamp(self):
        """Test case for add_message_stamp

        スタンプを押す  # noqa: E501
        """
        pass

    def test_change_stamp_image(self):
        """Test case for change_stamp_image

        スタンプ画像を変更  # noqa: E501
        """
        pass

    def test_create_stamp(self):
        """Test case for create_stamp

        スタンプを作成  # noqa: E501
        """
        pass

    def test_create_stamp_palette(self):
        """Test case for create_stamp_palette

        スタンプパレットを作成  # noqa: E501
        """
        pass

    def test_delete_stamp(self):
        """Test case for delete_stamp

        スタンプを削除  # noqa: E501
        """
        pass

    def test_delete_stamp_palette(self):
        """Test case for delete_stamp_palette

        スタンプパレットを削除  # noqa: E501
        """
        pass

    def test_edit_stamp(self):
        """Test case for edit_stamp

        スタンプ情報を変更  # noqa: E501
        """
        pass

    def test_edit_stamp_palette(self):
        """Test case for edit_stamp_palette

        スタンプパレットを編集  # noqa: E501
        """
        pass

    def test_get_message_stamps(self):
        """Test case for get_message_stamps

        メッセージのスタンプリストを取得  # noqa: E501
        """
        pass

    def test_get_my_stamp_history(self):
        """Test case for get_my_stamp_history

        スタンプ履歴を取得  # noqa: E501
        """
        pass

    def test_get_stamp(self):
        """Test case for get_stamp

        スタンプ情報を取得  # noqa: E501
        """
        pass

    def test_get_stamp_image(self):
        """Test case for get_stamp_image

        スタンプ画像を取得  # noqa: E501
        """
        pass

    def test_get_stamp_palette(self):
        """Test case for get_stamp_palette

        スタンプパレットを取得  # noqa: E501
        """
        pass

    def test_get_stamp_palettes(self):
        """Test case for get_stamp_palettes

        スタンプパレットのリストを取得  # noqa: E501
        """
        pass

    def test_get_stamp_stats(self):
        """Test case for get_stamp_stats

        スタンプ統計情報を取得  # noqa: E501
        """
        pass

    def test_get_stamps(self):
        """Test case for get_stamps

        スタンプリストを取得  # noqa: E501
        """
        pass

    def test_remove_message_stamp(self):
        """Test case for remove_message_stamp

        スタンプを消す  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
