"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.star_api import StarApi  # noqa: E501


class TestStarApi(unittest.TestCase):
    """StarApi unit test stubs"""

    def setUp(self):
        self.api = StarApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_add_my_star(self):
        """Test case for add_my_star

        チャンネルをスターに追加  # noqa: E501
        """
        pass

    def test_get_my_stars(self):
        """Test case for get_my_stars

        スターチャンネルリストを取得  # noqa: E501
        """
        pass

    def test_remove_my_star(self):
        """Test case for remove_my_star

        チャンネルをスターから削除します  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
