"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.file_api import FileApi  # noqa: E501


class TestFileApi(unittest.TestCase):
    """FileApi unit test stubs"""

    def setUp(self):
        self.api = FileApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_file(self):
        """Test case for delete_file

        ファイルを削除  # noqa: E501
        """
        pass

    def test_get_file(self):
        """Test case for get_file

        ファイルをダウンロード  # noqa: E501
        """
        pass

    def test_get_file_meta(self):
        """Test case for get_file_meta

        ファイルメタを取得  # noqa: E501
        """
        pass

    def test_get_files(self):
        """Test case for get_files

        ファイルメタのリストを取得  # noqa: E501
        """
        pass

    def test_get_thumbnail_image(self):
        """Test case for get_thumbnail_image

        サムネイル画像を取得  # noqa: E501
        """
        pass

    def test_post_file(self):
        """Test case for post_file

        ファイルをアップロード  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
