# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from traq.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from traq.model.active_o_auth2_token import ActiveOAuth2Token
from traq.model.activity_timeline_message import ActivityTimelineMessage
from traq.model.bot import Bot
from traq.model.bot_detail import BotDetail
from traq.model.bot_event_log import BotEventLog
from traq.model.bot_event_result import BotEventResult
from traq.model.bot_mode import BotMode
from traq.model.bot_state import BotState
from traq.model.bot_tokens import BotTokens
from traq.model.bot_user import BotUser
from traq.model.channel import Channel
from traq.model.channel_event import ChannelEvent
from traq.model.channel_list import ChannelList
from traq.model.channel_stats import ChannelStats
from traq.model.channel_stats_stamp import ChannelStatsStamp
from traq.model.channel_stats_user import ChannelStatsUser
from traq.model.channel_subscribe_level import ChannelSubscribeLevel
from traq.model.channel_topic import ChannelTopic
from traq.model.channel_view_state import ChannelViewState
from traq.model.channel_viewer import ChannelViewer
from traq.model.child_created_event import ChildCreatedEvent
from traq.model.clip_folder import ClipFolder
from traq.model.clipped_message import ClippedMessage
from traq.model.dm_channel import DMChannel
from traq.model.external_provider_user import ExternalProviderUser
from traq.model.file_info import FileInfo
from traq.model.file_info_thumbnail import FileInfoThumbnail
from traq.model.forced_notification_changed_event import ForcedNotificationChangedEvent
from traq.model.get_notify_citation import GetNotifyCitation
from traq.model.login_session import LoginSession
from traq.model.message import Message
from traq.model.message_clip import MessageClip
from traq.model.message_pin import MessagePin
from traq.model.message_search_result import MessageSearchResult
from traq.model.message_stamp import MessageStamp
from traq.model.my_channel_view_state import MyChannelViewState
from traq.model.my_user_detail import MyUserDetail
from traq.model.name_changed_event import NameChangedEvent
from traq.model.o_auth2_client import OAuth2Client
from traq.model.o_auth2_client_detail import OAuth2ClientDetail
from traq.model.o_auth2_prompt import OAuth2Prompt
from traq.model.o_auth2_response_type import OAuth2ResponseType
from traq.model.o_auth2_scope import OAuth2Scope
from traq.model.o_auth2_token import OAuth2Token
from traq.model.ogp import Ogp
from traq.model.ogp_media import OgpMedia
from traq.model.parent_changed_event import ParentChangedEvent
from traq.model.patch_bot_request import PatchBotRequest
from traq.model.patch_channel_request import PatchChannelRequest
from traq.model.patch_channel_subscribers_request import PatchChannelSubscribersRequest
from traq.model.patch_client_request import PatchClientRequest
from traq.model.patch_clip_folder_request import PatchClipFolderRequest
from traq.model.patch_group_member_request import PatchGroupMemberRequest
from traq.model.patch_me_request import PatchMeRequest
from traq.model.patch_stamp_palette_request import PatchStampPaletteRequest
from traq.model.patch_stamp_request import PatchStampRequest
from traq.model.patch_user_group_request import PatchUserGroupRequest
from traq.model.patch_user_request import PatchUserRequest
from traq.model.patch_user_tag_request import PatchUserTagRequest
from traq.model.patch_webhook_request import PatchWebhookRequest
from traq.model.pin import Pin
from traq.model.pin_added_event import PinAddedEvent
from traq.model.pin_removed_event import PinRemovedEvent
from traq.model.post_bot_action_join_request import PostBotActionJoinRequest
from traq.model.post_bot_action_leave_request import PostBotActionLeaveRequest
from traq.model.post_bot_request import PostBotRequest
from traq.model.post_channel_request import PostChannelRequest
from traq.model.post_client_request import PostClientRequest
from traq.model.post_clip_folder_message_request import PostClipFolderMessageRequest
from traq.model.post_clip_folder_request import PostClipFolderRequest
from traq.model.post_link_external_account import PostLinkExternalAccount
from traq.model.post_login_request import PostLoginRequest
from traq.model.post_message_request import PostMessageRequest
from traq.model.post_message_stamp_request import PostMessageStampRequest
from traq.model.post_my_fcm_device_request import PostMyFCMDeviceRequest
from traq.model.post_stamp_palette_request import PostStampPaletteRequest
from traq.model.post_star_request import PostStarRequest
from traq.model.post_unlink_external_account import PostUnlinkExternalAccount
from traq.model.post_user_group_admin_request import PostUserGroupAdminRequest
from traq.model.post_user_group_request import PostUserGroupRequest
from traq.model.post_user_request import PostUserRequest
from traq.model.post_user_tag_request import PostUserTagRequest
from traq.model.post_web_rtc_authenticate_request import PostWebRTCAuthenticateRequest
from traq.model.post_webhook_request import PostWebhookRequest
from traq.model.put_channel_subscribe_level_request import PutChannelSubscribeLevelRequest
from traq.model.put_channel_subscribers_request import PutChannelSubscribersRequest
from traq.model.put_channel_topic_request import PutChannelTopicRequest
from traq.model.put_my_password_request import PutMyPasswordRequest
from traq.model.put_notify_citation_request import PutNotifyCitationRequest
from traq.model.put_user_password_request import PutUserPasswordRequest
from traq.model.stamp import Stamp
from traq.model.stamp_history_entry import StampHistoryEntry
from traq.model.stamp_palette import StampPalette
from traq.model.stamp_stats import StampStats
from traq.model.subscribers_changed_event import SubscribersChangedEvent
from traq.model.tag import Tag
from traq.model.thumbnail_info import ThumbnailInfo
from traq.model.thumbnail_type import ThumbnailType
from traq.model.topic_changed_event import TopicChangedEvent
from traq.model.unread_channel import UnreadChannel
from traq.model.user import User
from traq.model.user_account_state import UserAccountState
from traq.model.user_detail import UserDetail
from traq.model.user_group import UserGroup
from traq.model.user_group_member import UserGroupMember
from traq.model.user_permission import UserPermission
from traq.model.user_settings import UserSettings
from traq.model.user_stats import UserStats
from traq.model.user_stats_stamp import UserStatsStamp
from traq.model.user_subscribe_state import UserSubscribeState
from traq.model.user_tag import UserTag
from traq.model.version import Version
from traq.model.version_flags import VersionFlags
from traq.model.visibility_changed_event import VisibilityChangedEvent
from traq.model.web_rtc_authenticate_result import WebRTCAuthenticateResult
from traq.model.web_rtc_user_state import WebRTCUserState
from traq.model.web_rtc_user_state_sessions import WebRTCUserStateSessions
from traq.model.web_rtc_user_states import WebRTCUserStates
from traq.model.webhook import Webhook
