"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import traq
from traq.model.pin_added_event import PinAddedEvent


class TestPinAddedEvent(unittest.TestCase):
    """PinAddedEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPinAddedEvent(self):
        """Test PinAddedEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PinAddedEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
