"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.oauth2_api import Oauth2Api  # noqa: E501


class TestOauth2Api(unittest.TestCase):
    """Oauth2Api unit test stubs"""

    def setUp(self):
        self.api = Oauth2Api()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_client(self):
        """Test case for create_client

        OAuth2クライアントを作成  # noqa: E501
        """
        pass

    def test_delete_client(self):
        """Test case for delete_client

        OAuth2クライアントを削除  # noqa: E501
        """
        pass

    def test_edit_client(self):
        """Test case for edit_client

        OAuth2クライアント情報を変更  # noqa: E501
        """
        pass

    def test_get_client(self):
        """Test case for get_client

        OAuth2クライアント情報を取得  # noqa: E501
        """
        pass

    def test_get_clients(self):
        """Test case for get_clients

        OAuth2クライアントのリストを取得  # noqa: E501
        """
        pass

    def test_get_my_tokens(self):
        """Test case for get_my_tokens

        有効トークンのリストを取得  # noqa: E501
        """
        pass

    def test_get_o_auth2_authorize(self):
        """Test case for get_o_auth2_authorize

        OAuth2 認可エンドポイント  # noqa: E501
        """
        pass

    def test_post_o_auth2_authorize(self):
        """Test case for post_o_auth2_authorize

        OAuth2 認可エンドポイント  # noqa: E501
        """
        pass

    def test_post_o_auth2_authorize_decide(self):
        """Test case for post_o_auth2_authorize_decide

        OAuth2 認可承諾API  # noqa: E501
        """
        pass

    def test_post_o_auth2_token(self):
        """Test case for post_o_auth2_token

        OAuth2 トークンエンドポイント  # noqa: E501
        """
        pass

    def test_revoke_my_token(self):
        """Test case for revoke_my_token

        トークンの認可を取り消す  # noqa: E501
        """
        pass

    def test_revoke_o_auth2_token(self):
        """Test case for revoke_o_auth2_token

        OAuth2 トークン無効化エンドポイント  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
