"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import traq
from traq.model.web_rtc_user_state_sessions import WebRTCUserStateSessions
globals()['WebRTCUserStateSessions'] = WebRTCUserStateSessions
from traq.model.web_rtc_user_state import WebRTCUserState


class TestWebRTCUserState(unittest.TestCase):
    """WebRTCUserState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testWebRTCUserState(self):
        """Test WebRTCUserState"""
        # FIXME: construct object with mandatory attributes with example values
        # model = WebRTCUserState()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
