"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.ogp_api import OgpApi  # noqa: E501


class TestOgpApi(unittest.TestCase):
    """OgpApi unit test stubs"""

    def setUp(self):
        self.api = OgpApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_ogp(self):
        """Test case for get_ogp

        OGP情報を取得  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
