"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.notification_api import NotificationApi  # noqa: E501


class TestNotificationApi(unittest.TestCase):
    """NotificationApi unit test stubs"""

    def setUp(self):
        self.api = NotificationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_edit_channel_subscribers(self):
        """Test case for edit_channel_subscribers

        チャンネルの通知購読者を編集  # noqa: E501
        """
        pass

    def test_get_channel_subscribers(self):
        """Test case for get_channel_subscribers

        チャンネルの通知購読者のリストを取得  # noqa: E501
        """
        pass

    def test_get_my_channel_subscriptions(self):
        """Test case for get_my_channel_subscriptions

        自分のチャンネル購読状態を取得  # noqa: E501
        """
        pass

    def test_get_my_unread_channels(self):
        """Test case for get_my_unread_channels

        未読チャンネルを取得  # noqa: E501
        """
        pass

    def test_get_my_view_states(self):
        """Test case for get_my_view_states

        自身のチャンネル閲覧状態一覧を取得  # noqa: E501
        """
        pass

    def test_read_channel(self):
        """Test case for read_channel

        チャンネルを既読にする  # noqa: E501
        """
        pass

    def test_register_fcm_device(self):
        """Test case for register_fcm_device

        FCMデバイスを登録  # noqa: E501
        """
        pass

    def test_set_channel_subscribe_level(self):
        """Test case for set_channel_subscribe_level

        チャンネル購読レベルを設定  # noqa: E501
        """
        pass

    def test_set_channel_subscribers(self):
        """Test case for set_channel_subscribers

        チャンネルの通知購読者を設定  # noqa: E501
        """
        pass

    def test_ws(self):
        """Test case for ws

        WebSocket通知ストリームに接続します  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
