"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import traq
from traq.model.user_account_state import UserAccountState
from traq.model.user_permission import UserPermission
from traq.model.user_tag import UserTag
globals()['UserAccountState'] = UserAccountState
globals()['UserPermission'] = UserPermission
globals()['UserTag'] = UserTag
from traq.model.my_user_detail import MyUserDetail


class TestMyUserDetail(unittest.TestCase):
    """MyUserDetail unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMyUserDetail(self):
        """Test MyUserDetail"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MyUserDetail()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
