"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import traq
from traq.model.thumbnail_type import ThumbnailType
globals()['ThumbnailType'] = ThumbnailType
from traq.model.thumbnail_info import ThumbnailInfo


class TestThumbnailInfo(unittest.TestCase):
    """ThumbnailInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testThumbnailInfo(self):
        """Test ThumbnailInfo"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ThumbnailInfo()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
