"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import traq
from traq.model.child_created_event import ChildCreatedEvent
from traq.model.forced_notification_changed_event import ForcedNotificationChangedEvent
from traq.model.name_changed_event import NameChangedEvent
from traq.model.parent_changed_event import ParentChangedEvent
from traq.model.pin_added_event import PinAddedEvent
from traq.model.pin_removed_event import PinRemovedEvent
from traq.model.subscribers_changed_event import SubscribersChangedEvent
from traq.model.topic_changed_event import TopicChangedEvent
from traq.model.visibility_changed_event import VisibilityChangedEvent
globals()['ChildCreatedEvent'] = ChildCreatedEvent
globals()['ForcedNotificationChangedEvent'] = ForcedNotificationChangedEvent
globals()['NameChangedEvent'] = NameChangedEvent
globals()['ParentChangedEvent'] = ParentChangedEvent
globals()['PinAddedEvent'] = PinAddedEvent
globals()['PinRemovedEvent'] = PinRemovedEvent
globals()['SubscribersChangedEvent'] = SubscribersChangedEvent
globals()['TopicChangedEvent'] = TopicChangedEvent
globals()['VisibilityChangedEvent'] = VisibilityChangedEvent
from traq.model.channel_event import ChannelEvent


class TestChannelEvent(unittest.TestCase):
    """ChannelEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testChannelEvent(self):
        """Test ChannelEvent"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ChannelEvent()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
