"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.webhook_api import WebhookApi  # noqa: E501


class TestWebhookApi(unittest.TestCase):
    """WebhookApi unit test stubs"""

    def setUp(self):
        self.api = WebhookApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_change_webhook_icon(self):
        """Test case for change_webhook_icon

        Webhookのアイコンを変更  # noqa: E501
        """
        pass

    def test_create_webhook(self):
        """Test case for create_webhook

        Webhookを新規作成  # noqa: E501
        """
        pass

    def test_delete_webhook(self):
        """Test case for delete_webhook

        Webhookを削除  # noqa: E501
        """
        pass

    def test_edit_webhook(self):
        """Test case for edit_webhook

        Webhook情報を変更  # noqa: E501
        """
        pass

    def test_get_webhook(self):
        """Test case for get_webhook

        Webhook情報を取得  # noqa: E501
        """
        pass

    def test_get_webhook_icon(self):
        """Test case for get_webhook_icon

        Webhookのアイコンを取得  # noqa: E501
        """
        pass

    def test_get_webhook_messages(self):
        """Test case for get_webhook_messages

        Webhookの投稿メッセージのリストを取得  # noqa: E501
        """
        pass

    def test_get_webhooks(self):
        """Test case for get_webhooks

        Webhook情報のリストを取得します  # noqa: E501
        """
        pass

    def test_post_webhook(self):
        """Test case for post_webhook

        Webhookを送信  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
