"""
    traQ v3

    traQ v3 API  # noqa: E501

    The version of the OpenAPI document: 3.0
    Generated by: https://openapi-generator.tech
"""


import unittest

import traq
from traq.api.pin_api import PinApi  # noqa: E501


class TestPinApi(unittest.TestCase):
    """PinApi unit test stubs"""

    def setUp(self):
        self.api = PinApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_pin(self):
        """Test case for create_pin

        ピン留めする  # noqa: E501
        """
        pass

    def test_get_channel_pins(self):
        """Test case for get_channel_pins

        チャンネルピンのリストを取得  # noqa: E501
        """
        pass

    def test_get_pin(self):
        """Test case for get_pin

        ピン留めを取得  # noqa: E501
        """
        pass

    def test_remove_pin(self):
        """Test case for remove_pin

        ピン留めを外す  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
